@@ -1,12 +1,14 @@
 # ghcn_station_counts.pl - Count stations in ghcn_fetch.pl station output
 
+## no critic (Documentation::RequirePodAtEnd)
+
 =head1 NAME
 
 Weather::GHCN::App::StationCounts - Count stations in Weather::GHCN::Fetch station output
 
 =head1 VERSION
 
-version v0.0.003
+version v0.0.004
 
 =head1 SYNOPSIS
 
@@ -21,16 +23,32 @@ See ghcn_station_counts.pl -help for details.
 ########################################################################
 # Pragmas
 ########################################################################
+
+# these are needed because perlcritic fails to detect that Object::Pad handles these things
+## no critic [ProhibitVersionStrings]
+## no critic [RequireUseWarnings]
+
 use v5.18;  # minimum for Object::Pad
 
 package Weather::GHCN::App::StationCounts;
 
-our $VERSION = 'v0.0.003';
-
+our $VERSION = 'v0.0.004';
 
 use feature 'signatures';
 no  warnings 'experimental::signatures';
 
+########################################################################
+# perlcritic rules
+########################################################################
+
+## no critic [ErrorHandling::RequireCarping]
+## no critic [Modules::ProhibitAutomaticExportation]
+## no critic [Subroutines::ProhibitSubroutinePrototypes]
+
+# due to use of postfix dereferencing, we have to disable these warnings
+## no critic [References::ProhibitDoubleSigils]
+
+
 ########################################################################
 # Export
 ########################################################################
@@ -41,32 +59,24 @@ use base 'Exporter';
 
 our @EXPORT = ( 'run' );
 
-########################################################################
-# perlcritic rules
-########################################################################
-
-## no critic [ErrorHandling::RequireCarping]
-## no critic [References::ProhibitDoubleSigils];
-## no critic [Subroutines::ProhibitSubroutinePrototypes]
-
-
 ########################################################################
 # Libraries
 ########################################################################
 use Getopt::Long    qw( GetOptionsFromArray );
 use Pod::Usage;
 use Const::Fast;
-use Hash::Wrap          {-lvalue => 1, -defined => 1, -as => '_wrap_hash'};
+use Hash::Wrap      {-lvalue => 1, -defined => 1, -as => '_wrap_hash'};
 use Const::Fast;
+use English         qw( -no_match_vars );
 
-use if $^O eq 'MSWin32', 'Win32::Clipboard';
+use if $OSNAME eq 'MSWin32', 'Win32::Clipboard';
 
 ########################################################################
 # Global delarations
 ########################################################################
 
 # is it ok to use Win32::Clipboard?
-our $USE_WINCLIP = $^O eq 'MSWin32';
+our $USE_WINCLIP = $OSNAME eq 'MSWin32';
 
 my $Opt;
 
@@ -76,6 +86,8 @@ my $Opt;
 
 const my $EMPTY  => q();        # empty string
 const my $SPACE  => q( );       # space character
+const my $COMMA  => q(,);       # comma character
+const my $DASH   => q(-);       # dash character
 const my $TAB    => qq(\t);     # tab character
 const my $TRUE   => 1;          # perl's usual TRUE
 const my $FALSE  => not $TRUE;  # a dual-var consisting of '' and 0
@@ -108,9 +120,10 @@ See ghcn_station_counts.pl -help for details.
 sub run ($progname, $argv_aref) {
 
     my %count;
-    
+
     $Opt = get_options($argv_aref);
 
+    ## no critic [RequireBriefOpen]
     my ( $output, $new_fh, $old_fh );
     if ( $Opt->outclip and $USE_WINCLIP ) {
         open $new_fh, '>', \$output
@@ -119,14 +132,14 @@ sub run ($progname, $argv_aref) {
     }
 
     my @files = $argv_aref->@*;
-    @files = ('-') unless @files;
-    
+    @files = ($DASH) unless @files;
+
     foreach my $file (@files) {
         my $fh;
-        if ($file eq '-') {
+        if ($file eq $DASH) {
             $fh = *STDIN;
         } else {
-            open ($fh, '<', $file) or die;
+            open $fh, '<', $file or die;
         }
 
         read_data( $fh, \%count );
@@ -136,6 +149,7 @@ sub run ($progname, $argv_aref) {
 
     foreach my $yr (sort { $a <=> $b } keys %count) {
         my $stn_count = keys %{ $count{$yr} };
+        ## no critic [ProhibitMagicNumbers]
         my $decade = (substr $yr, 0, 3) . '0s';
         say sprintf "%3d\t%s\t%d", $yr, $decade, $stn_count;
     }
@@ -144,7 +158,7 @@ WRAP_UP:
     # send output to the Windows clipboard
     if ( $Opt->outclip and $USE_WINCLIP ) {
         Win32::Clipboard->new()->Set( $output );
-        select $old_fh;
+        select $old_fh; ## no critic [ProhibitOneArgSelect]
     }
 
 
@@ -157,8 +171,8 @@ WRAP_UP:
 
 =head2 read_data( $fh, \%count )
 
-From the file handle $fh, read a list of stations in the format 
-generated by Fetch.pm, and count the stations that were active in any 
+From the file handle $fh, read a list of stations in the format
+generated by Fetch.pm, and count the stations that were active in any
 given year.
 
 =cut
@@ -214,7 +228,7 @@ sub parse_active_range ($stnid, $active) {
         my $s = $active;
         $s =~ s{ [,] }{}xmsg;
         if ( $s =~ m{ (\d\d\d\d) (\d\d\d\d) }xms ) {
-            $active = $1 . '-' . $2;
+            $active = $1 . $DASH . $2;
         }
     }
 
@@ -223,7 +237,7 @@ sub parse_active_range ($stnid, $active) {
         return;
     }
 
-    my @rangelist = split ",", $active;
+    my @rangelist = split $COMMA, $active;
 
     return @rangelist;
 }
